Changelog
=========

0.1
---

First release with HTTP backend

0.2
---

 * SFTP backend, code mostly lifted from the SFTP backend from django-storages
 * fixed a bug that made it impossible to upload new files when using the dev storage